import { ObjectId } from 'mongodb';
import DBFleet from '../../types/db/DBFleet';
import { Planet } from '../classes/managers/PlanetManager';
import { Fleet, Planets } from '../db/mongodb';

export const getAllFleet = async () => {
    return (await Fleet()).find({}).toArray() as unknown as Array<DBFleet>;
}

export const getAllFleetByUser = async (userId: ObjectId) => {
    const planets = await (await Planets()).find({ owner: userId }).toArray();

    const fleets = new Map<string, DBFleet>();

    for(const planet of planets) {
        const fleet = await (await Fleet()).find({ $or: [
            { source: planet._id },
            { destination: planet._id }
        ] }).toArray() as unknown as DBFleet[];

        for(const f of fleet) {
            fleets.set(f._id.toString(), f);
        }
    }

    return Array.from(fleets.values());
}

export const createFleet = async (source: Planet, destination: Planet, mission: string, ships: Array<{ id: string, amount: number }>) => {
    const fleet = {
        source: source._id,
        destination: destination._id,
        finished: false,
        returning: false,
        mission,
        ships
    }
    
    await (await Fleet()).insertOne(fleet);
}